importPackage( dw.order );
importPackage( dw.system );

/**
 * After an order is created via the OCAPI, we check whether it was created via Grin
 * by checking for the automated Grin note. If the order was created via Grin, we
 * get the configuration preferences set for the current site and run the order through
 * a series of conditional updates.
 *
 * @param  {dw.order.Order} order
 * @return {dw.system.Status}
 */
exports.afterPOST = function(order) {
    var config = dw.system.Site.getCurrent().preferences.custom;

    if (!orderWasCreatedViaGrin(order) || !config.grinPlaceOrders) {
        return new dw.system.Status(dw.system.Status.OK);
    }

    dw.order.OrderMgr.placeOrder(order);

    if (config.grinPrepareOrdersForExport) {
        order.setExportStatus(dw.order.Order.EXPORT_STATUS_READY);
    }

    if (config.grinConfirmOrders) {
        order.setConfirmationStatus(dw.order.Order.CONFIRMATION_STATUS_CONFIRMED);
    }

    if (config.grinPayOrders) {
        order.setPaymentStatus(dw.order.Order.PAYMENT_STATUS_PAID);
    }

    return new dw.system.Status(dw.system.Status.OK);
};

/**
 * Whether the order was created via Grin
 *
 * @param  {dw.order.Order} order
 * @return {boolean}
 */
function orderWasCreatedViaGrin(order) {
    for (var i = 0; i < order.getNotes().length; i++) {
        var note = order.getNotes().get(i);

        if (note.getSubject() === 'Grin') {
            return true;
        }
    }

    return false;
}